#
# spec file for package capnet-assist
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid io.elementary.capnet-assist
Name:           capnet-assist
Version:        8.0.0
Release:        1.1
Summary:        Captive Portal Assistant
License:        GPL-3.0-or-later
URL:            https://github.com/elementary/capnet-assist
Source:         %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson >= 0.57
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala >= 0.28.0
BuildRequires:  pkgconfig(gcr-4)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(granite-7) >= 7.0.0
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(webkitgtk-6.0)
Requires:       NetworkManager
Provides:       elementary-capnet-assist = %{version}
Obsoletes:      elementary-capnet-assist < %{version}

%description
Assists users in connective to Captive Portals such as those found on
public access points in train stations, coffee shops, universities, etc.
Upon detection, the assistant appears showing the captive portal. Once a
connection is known to have been established, it dismisses itself. Written
in Vala and using WebkitGtk+.

%lang_package

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install
%suse_update_desktop_file %{appid}
%find_lang %{appid}
%fdupes %{buildroot}%{_datadir}/icons

%files
%license COPYING
%doc README.md
%{_bindir}/%{appid}
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_iconsdir}/hicolor/*/apps/%{appid}.svg
%{_datadir}/metainfo/%{appid}.metainfo.xml
%dir %{_iconsdir}/hicolor/{128x128@2,128x128@2/apps,16x16@2,16x16@2/apps,24x24@2,24x24@2/apps,32x32@2,32x32@2/apps,64x64@2,64x64@2/apps}

%files lang -f %{appid}.lang

%changelog
* Fri Aug  9 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.0:
  * Update to elementary runtime 8
  * Performance improvements
  * Updated translations
- update to 2.4.4:
  * Metainfo improvements
  * Update translation files
- update to 2.4.3:
  * Update to elementary runtime 7.1
  * Updated translations
- change url to github, as we don't want to link to their own OS
* Sat Jun 25 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to 2.4.2:
  * Update to elementary runtime 7
  * Updated translations
- Changes from 2.4.1:
  * Update to elementary runtime 6.1
  * Updated translation
- Changes from 2.4.0:
  * New icon
  * Updated translations
- Changes from 2.3.0:
  * Dark style support
  * Updated translations
- New build dependency: pkgconfig(libhandy-1)
* Sun Nov  1 2020 Manu Maier <mmanu84@outlook.de>
- Update to 2.2.5:
  * Replace Granite.Services.Settings with GLib.Settings (#51)
* Mon Nov 25 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.2.4:
  * Travis: Downgrade node to 10 to fix CI
  * Add Gettext Updates to Actions
  * README: Fix weblate badge
  * Delete AUTHORS
  * Add Release to Actions
  * AppData: Add releases info
  * Add Lint to CI (#49)
  * Fix code style issues
  * Delete CODE_OF_CONDUCT.md
  * Fix wrong merge
  * Merge remote-tracking branch 'weblate/master'
  * Application.vala: Replace "the following URL" with "this
    address" (#46)
* Mon Mar  4 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.2.3:
  * Spelling: following URL in, + Copyright year updated (#43)
  * Travis: Use Houston CI (#41)
* Wed Oct 17 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.2.2:
  * Meson: Use GLib preset for l10n
  * Add a fake example captive portal and a screenshot (#37)
  * Merge branch 'origin/master' into Weblate
  * Add an appdata file (#36)
  * CertButton.vala: Wrap primary label (#35)
* Mon Oct  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.2.1:
  * This release includes updated translations.
* Sat Jun  9 2018 avvissu@yandex.by
- Update to 0.2.2:
  * use new symbolic security icons (#30)
  * Use native portal checking (#23)
  * Merge remote-tracking branch 'origin/master'
* Fri Jun  8 2018 avvissu@yandex.by
- Switch to git from bzr
- Switch to meson
- Buils with dependences: gconfig(glib-2.0) pkgconfig(gobject-2.0)
- Add NetworkManager as required dependency
- Remove obsolete macros
- Spec file cleanup
* Thu Jan 19 2017 avvissu@yandex.by
- Update to 0.2.1:
  * Change the capnet dummy URL address
  * Launchpad automatic translations update.
  * Add 2017 to license copyright and app years.
  * Add GSetting to enable the assistant
  * move the TLS popover code to the cert_button class
  * Pass Downloads to a web browser
  * New Window & tab requests are put into their own tabs
  * update translation template
  * CaptiveLogin.vala: Use the construct method
  * CaptiveLogin.vala:
  * Eliminate the variable view_security
  * Only check security once to assign style classes in the
    popover
  * CertButton.vala:
  * Make security a gettable property
  * Move captivity check to the application class
  * Update license header
  * return privacy mode without creating a variable
  * remove extra comment
* Tue Sep 20 2016 avvissu@yandex.by
- Add Recommends: capnet-assist-lang
* Sat Sep 10 2016 mailaender@opensuse.org
- update to version 0.2.0.1
* Thu Mar 10 2016 and.november@opensuse.org
- update
* Sat Sep 26 2015 and.november@opensuse.org
- initial package (version 0.1.1) for build.opensuse.org
